databases: agenda: [ ] escrow [ ] account balances vernacular: squashes structure: [DB] accounts [collection] span-1 [collection] span-2 [DB] accounts-squashes [collection] squash-1 [{ "public": "3043300506032b6571033a005bed4824c5853fd1a296d25ba0f64e9a36781ce9d7268182f67b7485670f4d9d4cba600b5393c768660a175289bbf63bddead92210bdab6900", "amount": "120304030" },{ "public": "", "amount": "120304030" },{ "public": "", "amount": "123" }] [DB] escrow [collection] span-1 [collection] span-2 [DB] escrow-squashes [collection] squash-1 collection_1 [{ # # These are sequential per squeeze # "date": 1, # # These are unique as they don't need signatures # "structural": "yes", "collection": 1, "proposal": "proposal key", "public key": "", "private key signature": "", "petition": {} },{ "date": 2, "structural": "yes", "collection": 1, "proposal": "friendship key", "public key": "", "private key signature": "", "petition": {} },{ "date": 3, # # These are unique as they don't need signatures # "founder": "yes", "collection": 1, "proposal": "create rings", "public key": "", "private key signature": "", "petition": {} }] collection_2 [] collection_3 [] collection_4 [] propose: "create rings" "proposal key" { "public key": "", "private key signature": "", "signatures": { public_key : "" } } "friendship key" { "public key": "", "private key signature": "", "signatures": { } }